==> like_sealed_gen-0.3.0.tar.gz: lib/src/content/sealed_switch_impl_content.dart <==
import 'package:analyzer/dart/element/element.dart';
import 'package:like_sealed_gen/src/util.dart';

class SealedSwitchImplContent {
  final String className;
  final List<ClassElement> types;

  SealedSwitchImplContent(this.className, this.types);

  String content() {
    String typeChecker = "";
    String field = "";
    List<String> constructorParameter = [];
    String caseFunction = "";
    for (var type in types) {
      final typeName = type.name;

      if (typeName == className) {
        typeChecker +=
            "(type is $typeName&& ${typeName.firstToLower} != null)? onDefault(type) : null";
        caseFunction +=
            "T onDefault($typeName value)=>${typeName.firstToLower}(value);";
        field += "final T Function($typeName)  ${typeName.firstToLower};";
        constructorParameter.add("this.${typeName.firstToLower}");
      } else {
        typeChecker +=
            "(type is $typeName && ${typeName.firstToLower} != null) ? on$typeName(type) : ";
        caseFunction +=
            "T on$typeName($typeName value)=>${typeName.firstToLower}(value);";
        field += "final T Function($typeName)  ${typeName.firstToLower};";
        constructorParameter.add("this.${typeName.firstToLower}");
      }
    }

    return """
    class ${className}SwitchImpl<T> implements ${className}Switch<T> {
      ${field}
      ${className}SwitchImpl({${constructorParameter.join(",")}});
      
      ${className}SwitchImpl.fill(${constructorParameter.join(",")});
      
       ${className}SwitchImpl.required({${constructorParameter.map((e) => "@required $e").join(",")}});
     
      T switchCase($className type)=>$typeChecker;
      
      $caseFunction
    }
    """;
  }
}

==> like_sealed_gen-0.4.0.tar.gz: lib/src/content/sealed_switch_impl_content.dart <==
import 'package:analyzer/dart/element/element.dart';
import 'package:like_sealed_gen/src/util.dart';

class SealedSwitchImplContent {
  final String className;
  final List<ClassElement> types;
  final bool isShortName;

  SealedSwitchImplContent(this.isShortName, this.className, this.types);

  String content() {
    String typeChecker = "";
    String field = "";
    List<String> constructorParameter = [];
    String caseFunction = "";
    for (var type in types) {
      final typeName = type.name;
      String functionName = typeName;
      if (isShortName) {
        functionName = functionName.removeIf(className);
      }
      if (typeName == className) {
        typeChecker +=
            "(type is $typeName&& ${typeName.firstToLower} != null)? onDefault(type) : null";
        caseFunction +=
            "T onDefault($typeName value)=>${typeName.firstToLower}(value);";
        field += "final T Function($typeName)  ${typeName.firstToLower};";
        constructorParameter.add("this.${typeName.firstToLower}");
      } else {
        typeChecker +=
            "(type is $typeName && ${functionName.firstToLower} != null) ? on$functionName(type) : ";
        caseFunction +=
            "T on$functionName($typeName value)=>${functionName.firstToLower}(value);";
        field += "final T Function($typeName)  ${functionName.firstToLower};";
        constructorParameter.add("this.${functionName.firstToLower}");
      }
    }

    return """
    class ${className}SwitchImpl<T> implements ${className}Switch<T> {
      ${field}
      ${className}SwitchImpl({${constructorParameter.join(",")}});
      
      ${className}SwitchImpl.fill(${constructorParameter.join(",")});
      
       ${className}SwitchImpl.required({${constructorParameter.map((e) => "@required $e").join(",")}});
     
      T switchCase($className type)=>$typeChecker;
      
      $caseFunction
    }
    """;
  }
}
